
.getDelim <- function(filename, seps = c("\t"," ",";",","), nrows = 10) {

  .check_file(filename)
  nbCol <- NULL
  for(i in 1:length(seps)){
    sep <- seps[i]
    df <- utils::read.csv(filename, sep = sep, nrows = nrows)
    nbCol <- c(nbCol, length(df))
  }
  iSep = which(nbCol==max(nbCol))[1]
  sep = seps[iSep]
  if (nbCol[iSep] == 1) {
    message(paste0("ERROR: Cannot read file ", filename, "."))
    return(invisible(NULL))
  }
  return(invisible(sep))
}

#' @importFrom readxl excel_sheets read_excel
#' @export
.readDataset <- function(filename, sheet = NULL) {
  filename <- .check_file(filename)
  fileext <- utils::tail(strsplit(filename, "\\.")[[1]], n=1)
  if (fileext %in% c("xls", "xlsx")) {
    if (!is.null(sheet)) {
      sheets <- excel_sheets(filename)
      for (indexSheet in 1:length(sheet)) {
        if (is.character(sheet[indexSheet])) {
          if (!sheet[indexSheet] %in% sheets) {
            warning(paste0("Sheet ", sheet, " does not exist in file ", filename,
                           ". First sheet will be returned"
            ))
            sheet[indexSheet] <- 1
          }
        } else if (!sheet[indexSheet] %in% seq_along(sheets)) {
          warning(paste0("Sheet ", sheet[indexSheet], " does not exist in file ", filename,
                         ". First sheet will be returned"
          ))
          sheet[indexSheet] <- 1

        }
      }
      df <- NULL
      for(indexSheet in 1:length(sheet)){
        df_sheet <- read_excel(filename, sheet = sheet[indexSheet])
        df <- rbind(df, df_sheet)
      }
    } else {
      df <- read_excel(filename)
    }

    if (nrow(df)==0){
      if (!is.null(sheet)) {
        stop(paste0("Cannot read sheet ",sheet," of file ", filename, "."))
      }else{
        stop(paste0("Cannot read file ", filename, "."))
      }
    }
    df <- .getRound(as.data.frame(df), 15, reporting = F)
    #df <- .roundDataFrame(df, nbDigits = 15)
  } else {
    sep <- .getDelim(filename)
    if (is.null(sep))
      stop(paste0("Cannot read file ", filename, "."))
    df <- utils::read.csv(filename, sep = sep)
    for (col in names(df)) {
      df[[col]]
    }
  }
  return(df)
}

#  .getStartTime <- function(df) {
#   subjocc <- .getSubjocc()
#   dfStart <- subset(lixoftConnectors::getDoseInformation(),
#                     select = c(subjocc, "time"))
#   dfStart <- stats::aggregate(
#     dfStart$time,
#     by = as.list(subset(dfStart, select = subjocc)),
#     FUN=max
#   )
#   dfStart <- .renameColumns(dfStart, "x", "startTime")
#   return(dfStart)
# }

.renameColumns <- function(df, oldName, newName){
  if (length(oldName) != length(newName)) {
    message("[ERROR] vector of old names and new names must match in size")
    return(df)
  }
  for (i in seq_along(oldName)) {
    old <- oldName[i]
    new <- newName[i]
    if (old %in% names(df)) {
      names(df)[names(df) == old] <- new
    }
  }
  return(df)
}

.orderDataset <- function(df) {
  headerTypes <- .lixoftCall("getData")$headerTypes
  headers <- .lixoftCall("getData")$header
  colOrder <- c()
  for (h in seq_along(headerTypes)) {
    if (headerTypes[h] %in% names(df)) {
      colOrder <- c(colOrder, headerTypes[h])
    } else if (headers[h] %in% names(df)) {
      colOrder <- c(colOrder, headers[h])
    }
  }
  colOrder <- c(colOrder, names(df)[!names(df) %in% c(headers, headerTypes)])
  df <- df[, colOrder]
  return(df)
}
