#-----------------------------------------------------------------------------------------------
# check if a file exists
.check_file <- function(filename, fileType = "File") {
  if (!file.exists(filename)){
    message("ERROR: ",fileType, " ", filename, " does not exist.")
    return(invisible(FALSE))
  }else{
    filename <- normalizePath(filename)
    return(filename)
  }
}

# check if an argument is a positive integer
.check_integer <- function(int, arg_name) {
  if (!(is.double(int) | is.integer(int)))
    stop("`", arg_name, "` must be a positive integer.", call. = FALSE)
  if (any(int <= 0) | !all(as.integer(int) == int))
    stop("`", arg_name, "` must be a positive integer.", call. = FALSE)
  return(int)
}

# check if an argument is a vector
.check_vector <- function(d, arg_name) {
  if (!is.vector(d))
    stop("`", arg_name, "` must be a vector.", call. = FALSE)
  return(d)
}

# # check if an argument is a double
# .check_double <- function(d, arg_name) {
#   if (!(is.double(d) | is.integer(d)))
#     stop("`", arg_name, "` must be a double.", call. = FALSE)
#   return(d)
# }
#
#
# # check if an argument is a positive double
# .check_pos_double <- function(d, arg_name) {
#   if (!(is.double(d) | is.integer(d)) | any(d <= 0))
#     stop("`", arg_name, "` must be a positive double.", call. = FALSE)
#   return(d)
# }
#
# # check if an argument is a string
# .check_char <- function(str, arg_name) {
#   if (!is.character(str)) {
#     stop("`", arg_name, "` must be a string.", call. = FALSE)
#   }
#   return(str)
# }

.check_range <- function(r, arg_name) {
  if (length(r) != 2)
    stop("`", arg_name, "` must be a vector of size 2.", call. = FALSE)
  return(r)
}

# check if an argument is a boolean
.check_bool <- function(bool, arg_name) {
  if (!is.logical(bool))
    stop("Argument `", arg_name, "` must be logical.", call. = FALSE)
  return(bool)
}

# check if an argument is a list with the required fields
.check_list <- function(l, argname, listNames = NULL) {
  if (!is.list(l))
    stop("'", argname, "' must be a list.", call. = F)
  if (!is.null(listNames)) {
    if (!all(is.element(listNames, names(l))))
      stop("Invalid '", argname, " '. Missing mandatory fields ",
           paste(setdiff(listNames, names(l)), collapse = ", "), ".", call. = FALSE)
    if (!all(is.element(names(l), listNames)))
      warning("Invalid fields in '", argname, "' will be ignored. ",
              paste(setdiff(names(l), listNames), collapse = ", "), " will be ignored.",
              call. = F)
  }
  return(invisible(TRUE))
}

# check if an argument contains allowed elements
.check_in_vector <- function(arg, arg_name, allowed_args) {
  if (!all(is.element(arg, allowed_args)))
    stop("Invalid ", arg_name, "': ", paste(setdiff(arg, allowed_args), collapse = ", "),
         ". Available elements: '",
         paste(allowed_args, collapse="', '"), "'", call. = FALSE)
  return(arg)
}

# # check if 2 vectors have the same size
# .check_vectors_length <- function(v1, v2, argname1, argname2) {
#   if (length(v1) != length(v2))
#     stop(argname1, " vector and ", argname2, " vector must have the same length.", call. = F)
#   return(invisible(TRUE))
# }
#
# .check_pk_dataset <- function() {
#   header_types <- pkx.getData()$headerTypes
#   mandatory_data <- c("amount", "id", "time", "observation")
#   columns_match <- is.element(mandatory_data, header_types)
#   if (!all(columns_match)) {
#     stop("NCA estimation recquires a PK dataset. Columns ",
#          paste(toupper(setdiff(mandatory_data, header_types)), collapse=", "),
#          " are missing.", call. = FALSE
#     )
#   }
#   return(invisible(TRUE))
# }
#
# .check_obs <- function(obs, argname) {
#   obsnames <- mlx.getObservationInformation()$name
#   if (is.null(obs)) {
#     obs <- obsnames[1]
#     if (length(obsnames) > 1)
#       message("No output has been specified, '", argname, "' set to ", obs, ".")
#   } else if (!is.element(obs, obsnames)) {
#     stop("Output ", obs, "doesn not exist. You must choose one of the following outputs: `", paste(obsnames, collapse = ", "), ".",
#          call. = FALSE)
#   }
#   return(obs)
# }
#
# .check_predname <- function(predHeader, argname) {
#   allowedNames <- c('popPred_medianCOV', 'popPred', 'indivPred_SAEM',
#                     'indivPred_mean', 'indivPred_mode')
#   if (!is.element(predHeader, allowedNames))
#     stop("Invalid `", argname, "`. Allowed names are: ",
#          paste(allowedNames, collapse=", "), ".", call. = FALSE)
#   return(predHeader)
# }

# .check_adminType <- function(adminType, argname) {
#   allowedNames <- c('intravenous', 'extravascular')
#   if (!all(is.element(adminType, allowedNames)))
#     stop("Invalid `", argname, "`. Allowed names are: ",
#          paste(allowedNames, collapse=", "), ".", call. = FALSE)
#   # if multiple admin types, check if lengths match
#   nbadmin <- .getNbAdmid()
#   if (nbadmin != length(adminType))
#     stop("Invalid `", argname, "` length. ", nbadmin, " found in dataset, ",
#          "so `", argname, "` must be of size ", nbadmin, ".", call. = FALSE)
# }

# .check_mandatory_arg <- function(arg, argName) {
#   if (is.null(arg))
#     stop("`", argName, "` is missing", call. = FALSE)
#   return(TRUE)
# }

.check_column_as_double <- function(column, columnName) {
  if (suppressWarnings(any(is.na(as.double(column))))) {
    stop(columnName, "  must contain double.", call. = FALSE)
  }
  column <- as.double(column)
  return(column)
}

#-----------------------------------------------------------------------------------------------
# Check if the header is part of the data set name
# header should be included in the data set name
.check_header <- function(data, header, headerName, asTxt = NULL) {

  if (!is.null(asTxt)) {
    txt <- paste0(". It is a mandatory argument as ", asTxt, ".")
  } else {
    txt <- ", it is a mandatory argument."
  }
  if (is.null(header)) {
    message(paste0("ERROR: `", headerName, "` is missing", txt))
    return(invisible(FALSE))
  }
  if (!is.character(headerName)) {
    message(paste0("ERROR: `", headerName, "`  must be a string."))
    return(invisible(FALSE))
  }

  dataName <- names(data)
  for (index in 1:length(dataName)) {
    if (length(grep(x = dataName[index], pattern = header)) > 0) {
      return(dataName[index])
    }
    if (length(grep(x = dataName[index],
                    pattern = sub(x = header,
                                  pattern = " ",
                                  replacement = "."))) > 0){
      return(dataName[index])
    }
  }
  message(paste0("ERROR: ", headerName, " `", header, "` not found in input dataset."))
  return(invisible(FALSE))
}

#-----------------------------------------------------------------------------------------------
# Check if the value is a double
.check_double <- function(arg, argName, asTxt = NULL, is.pos = F, is.int = F) {

  if (!is.null(asTxt)) {
    txt <- paste0(". It is a mandatory argument as ", asTxt, ".")
  } else {
    txt <- ", it is a mandotary argument."
  }
  if (is.null(arg)) {
    message(paste0("ERROR: `", argName, "` is missing", txt))
    return(invisible(FALSE))
  }
  if (!(is.double(arg) | is.integer(arg))) {
    message("ERROR: `", paste0(argName, "`` must be a double."))
    return(invisible(FALSE))
  }

  if (is.pos) {
    if(arg <= 0) {
      message("ERROR: ", paste0(argName," must be a strictly positive double."))
      return(invisible(FALSE))
    }
  }

  if (is.int){
    if (!(abs(arg - floor(arg)) < .001 * abs(arg))) {
      message("ERROR: ", paste0(argName, " must be an integer."))
      return(invisible(FALSE))
    }
  }
  return(arg)
}



.check_arg_on_condition <- function(arg, argName, condition) {
  if (is.null(arg))
    stop("When ", condition, " `", argName, "` must be specified.", call. = FALSE)
  return(arg)
}

.check_ignoring_arg_on_condition <- function(arg, argName, condition) {
  if (!is.null(arg)) {
    warning("When ", condition, ", `", argName, "` is ignored.", call. = FALSE)
    arg <- NULL
  }
  return(arg)
}

# .check_datatype <- function(type, argName) {
#   if (!is.element(type, c("urine", "plasma")))
#     stop("`", argName, "` must be either `urine` or `plasma`", call. = FALSE)
#   return(type)
# }

.checkProjectFilename <- function(projectFilename, ext = NULL) {
  if(!is.null(projectFilename)){
    # if(file.exists(projectFilename))
    #   stop("Project '", projectFilename, "' already exists", call. = FALSE)
    fileext <- .getFileExt(projectFilename)
    if (is.null(fileext)) {
      projectFilename <- paste0(projectFilename, ".", ext)
    } else if (fileext != ext) {
      stop("Project '", projectFilename, "' should have a .", ext, " extension.", call. = FALSE)
    }
  }
  return(projectFilename)
}

.checkDatasetFilename <- function(datasetFilename) {
  if(!is.null(datasetFilename)){
    # if(file.exists(datasetFilename))
    #   stop("File '", datasetFilename, "' already exists", call. = FALSE)

    # Check if the extension is valid ("csv" or "txt")
    ext <- .getFileExt(datasetFilename)
    if (is.null(ext)) {
      datasetFilename <-  paste0(datasetFilename, ".csv")
    } else if (! is.element(ext, c("csv", "txt"))) {
      stop("Data file ", datasetFilename, " extension must be one of: {\"",
           paste(c("csv", "txt"), collapse="\", \""), "\"}.",
           call. = FALSE)
    }
  }
  return(invisible(TRUE))
}
#
# # Check Split list has correct elements and correct fields
# #' @importFrom stats na.omit
# .checkSplit <- function(split) {
#   if (is.null(split)) return(split)
#   # split = list(list(name = "occ"), list(name = "age", breaks = c(5, 10)))
#   cov <- pkx.getCovariateInformation()$covariate
#
#   # When only one output --> create a list of output
#   if (is.element("name", names(split))) {
#     split <- list(split)
#   }
#   # Split must be a list of lists
#   if (!is.list(split)) stop("Invalid 'split' argument. It must be a list object.", call. = FALSE)
#   if (!all(sapply(split, function(s) is.list(s))))
#     stop("Invalid 'split' list. All split elements must be lists with at least a field 'name'.", call. = FALSE)
#
#   allowedSplit <- na.omit(.matchToData(c("occ", "catcov", "contcov")))
#   splitNames <- sapply(split, function(s) s$name)
#
#   if (any(is.null(splitNames)))
#     stop("Invalid 'split' list. All split elements must be lists with at least a field 'name'.", call. = FALSE)
#
#   if (any(!is.element(splitNames, allowedSplit))) {
#     stop("Invalid 'split' list. Unkonwn split names: ", paste(setdiff(splitNames, allowedSplit), collapse = ", "),
#          ". You must select splits in {'", paste(allowedSplit, collapse = "', '"), "'}", call. = FALSE)
#   }
#
#   for (i in seq_along(split)) {
#     s <- split[[i]]
#     sname <- s$name
#     # categorical splits
#     if (sname %in% na.omit(.matchToData(c("occ", "catcov")))) {
#       .check_list(s, argname = paste("Categorical split element", sname), listNames = c("name"))
#       split[[i]] <- s[names(s) == "name"]
#     }
#
#     # continuous splits
#     if (sname %in% na.omit(.matchToData(c("contcov")))) {
#       .check_list(s, argname = paste("Continuous split element", sname), listNames = c("name", "breaks"))
#       .check_double(s$breaks, paste("breaks field in split element", sname))
#       s$breaks <- unique(sort(c(min(cov[[sname]]), s$breaks, max(cov[[sname]]))))
#       split[[i]] <- s[names(s) %in% c("name", "breaks")]
#     }
#   }
#   return(split)
# }
#
# # Check colors settings for plotConcentration
# .checkObsColorsSettings <- function(settings) {
#   .check_bool(settings$colorByGroup, "colors settings colorByGroup ")
#   .check_bool(settings$colorById, "colors settings colorById ")
#   if (settings$colorByGroup & settings$colorById) {
#     stop("Invalid color settings. Impossible to color by ids and by group at the same time.", call. = F)
#   }
#   return(invisible(TRUE))
# }
#
# .checkPlotSettings <- function(settings) {
#   .check_bool(settings$legend, "legend")
#   .check_bool(settings$grid, "grid")
#   .check_bool(settings$xlog, "xlog")
#   .check_bool(settings$ylog, "ylog")
#   .check_integer(settings$bins, "bins")
#   if (!is.null(settings$xlab)) .check_char(settings$xlab, "xlab")
#   if (!is.null(settings$ylab)) .check_char(settings$ylab, "ylab")
#   if (!is.null(settings$title)) .check_char(settings$title, "title")
#   .check_integer(settings$ncol, "ncol")
# }
#
# # Check Split list has correct elements and correct fields
# .checkTrendLines <- function(trendlines) {
#   if (is.null(trendlines)) return(invisible(TRUE))
#   .check_list(trendlines, "trendlines")
#   if (!all(sapply(trendlines, function(s) is.list(s))))
#     stop("Invalid 'trendlines' list. All trendlines elements must be lists with at least a field 'value'.", call. = FALSE)
#
#   allowedNames <- c("value", "label", "linetype", "color")
#   for (l in trendlines) {
#     if (!is.element("value", names(l)))
#       stop("Invalid 'trendlines' list. All trendlines elements must be lists with at least a field 'value'.", call. = FALSE)
#     .check_in_vector(names(l), "trendlines fields", allowedNames)
#   }
#   return(invisible(TRUE))
# }

# Check Ids provided exist
.checkIds <- function(ids) {
  if (is.null(ids)) return(invisible(TRUE))
  obs <- .lixoftCall("getObservationInformation")$concentration
  if (!all(is.element(ids, unique(obs$id)))) {
    stop("Invalid argument 'ids'. Unknown ids ",
         paste(setdiff(ids, unique(obs$id)), collapse = ", "), ".", call. = FALSE)
  }
  return(invisible(TRUE))
}
#
# # Check Filter list has correct elements and correct fields
# .checkFilter <- function(filter) {
#   if (is.null(filter)) return(filter)
#   # filter = list(list(name = "occ", cat = c(1)), list(name = "age", min = c(0, 70), max = c(10, 100)))
#   cov <- pkx.getCovariateInformation()$covariate
#
#   # When only one output --> create a list of output
#   if (is.element("name", names(filter))) {
#     filter <- list(filter)
#   }
#   # Filter must be a list of lists
#   if (!is.list(filter)) stop("Invalid 'filter' argument. It must be a list object.", call. = FALSE)
#   if (!all(sapply(filter, function(f) is.list(f))))
#     stop("Invalid 'filter' list. All filter elements must be lists with at least a field 'name'.", call. = FALSE)
#
#   allowedFilt <- na.omit(.matchToData(c("occ", "catcov", "contcov")))
#   filtNames <- sapply(filter, function(f) f$name)
#
#   if (any(is.null(filtNames)))
#     stop("Invalid 'filter' list. All filter elements must be lists with at least a field 'name'.", call. = FALSE)
#
#   if (any(!is.element(filtNames, allowedFilt))) {
#     stop("Invalid 'filter' list. Unkonwn filter names: ", paste(setdiff(filtNames, allowedFilt), collapse = ", "),
#          ". You must select filters in {'", paste(allowedFilt, collapse = "', '"), "'}", call. = FALSE)
#   }
#
#   for (i in seq_along(filter)) {
#     f <- filter[[i]]
#     fname <- f$name
#     # categorical splits
#     if (fname %in% na.omit(.matchToData(c("occ", "catcov")))) {
#       .check_list(f, argname = paste("Categorical filter element", fname), listNames = c("name", "cat"))
#       .check_in_vector(f$cat, arg_name = paste("Categories in filter element", fname), allowed_args = unique(cov[[fname]]))
#       filter[[i]] <- f[names(f) %in% c("name", "cat")]
#     }
#
#     # continuous splits
#     if (fname %in% na.omit(.matchToData(c("contcov")))) {
#       .check_list(f, argname = paste("Continuous filter element", fname), listNames = c("name", "interval"))
#       if (is.vector(f$interval) & length(f$interval) == 2) f$interval <- list(f$interval)
#       .check_list(f$interval, argname = paste("interval of continuous filter element", fname))
#       for (interval in f$interval) {
#         if (!all(sapply(f$interval, function(i) length(i) == 2))) {
#           stop("Invalid filter element", fname, ". Interval elements must be of length 2: c(min, max) with min < max", call. = FALSE)
#         }
#         if (!all(sapply(f$interval, function(i) i[1] < i[2]))) {
#           stop("Invalid filter element", fname, ". Interval elements must be of length 2: c(min, max) with min < max", call. = FALSE)
#         }
#       }
#       f$min <- sapply(f$interval, function(i) i[1])
#       f$max <- sapply(f$interval, function(i) i[2])
#       f$breaks <- unique(sort(c(min(cov[[fname]]), do.call(c, f$interval), max(cov[[fname]]))))
#       f$breaks <- f$breaks[(f$breaks >= min(cov[[fname]])) & (f$breaks <= max(cov[[fname]]))]
#       filter[[i]] <- f[names(f) %in% c("name", "interval", "breaks", "min", "max")]
#     }
#   }
#   return(filter)
# }
#
# .check_object_class <- function(arg, arg_name, arg_class) {
#   if (any(class(arg) != arg_class))
#     stop("`", arg_name, "` must be a `", arg_class, "` object.")
#   return(arg)
# }
#
# .check_bins <- function(binsSettings, argname) {
#   if (is.null(binsSettings)) {
#     binsSettings <- getBinsSettings()
#   }
#   .check_object_class(binsSettings, "binsSettings", "binSettingsClass")
#   return(binsSettings)
# }
