% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/adaptDataPkx.R
\name{formatData}
\alias{formatData}
\title{Adapt dataset for Pkanalix}
\usage{
formatData(
  dataFilename,
  dataType = "plasma",
  idHeader = NULL,
  obsHeader = NULL,
  timeHeader = NULL,
  occHeader = NULL,
  admIdHeader = NULL,
  urineStartTimeHeader = NULL,
  urineEndTimeHeader = NULL,
  urineVolumeHeader = NULL,
  is.multiDose = FALSE,
  addOccperDose = FALSE,
  is.timeSinceLastDose = FALSE,
  dosingOccHeader = NULL,
  timeFirstDose = 0,
  doseInterval = NULL,
  nbDoses = NULL,
  tInf = NULL,
  doseAmount = NULL,
  doseHeader = NULL,
  censTag = NULL,
  lloq = NULL,
  dataSheet = 1,
  createProject = F,
  outputFilename = NULL,
  catCov = NULL,
  contCov = NULL,
  export = TRUE
)
}
\arguments{
\item{dataFilename}{(\emph{string}) a dataset filename. It can be a txt file,
a csv file, an excel xls/xlsx file.}

\item{dataType}{(\emph{string}) Type of data. One of {"plasma", "urine"}
("plasma" by default)}

\item{idHeader}{(\emph{string}) Header of the column containing ID
information.}

\item{obsHeader}{(\emph{string} or \emph{vector}) Header name or vector of
header names of the columns containing OBSERVATION information.}

\item{timeHeader}{(\emph{string}) Header of the column containing TIME
information. To define when dataType = "plasma}

\item{occHeader}{(\emph{string} or \emph{vector}) Header name or vector of
header names of the columns containing OCCASION information. (by default no
occasion is considered)}

\item{admIdHeader}{(\emph{string}) Header of the column containing
ADMINISTRATION ID information (has to be in occHeader as well).}

\item{urineStartTimeHeader}{(\emph{string}) Header of the column containing
start time of urine collection intervals information. To define when
dataType = "urine"}

\item{urineEndTimeHeader}{(\emph{string}) Header of the column containing end
time of urine collection intervals information. To define when dataType =
"urine"}

\item{urineVolumeHeader}{(\emph{string}) Header of the column containing
urine collection volume information. To define when dataType = "urine"}

\item{is.multiDose}{(\emph{bool}) If TRUE, multiple doses / If FALSE, single
dose (default FALSE)}

\item{addOccperDose}{(\emph{bool}) If TRUE, each dosing will be marked as
different occasion (default FALSE)}

\item{is.timeSinceLastDose}{(\emph{bool}) If TRUE, time in dataset is
expressed as time after dose (default FALSE).}

\item{dosingOccHeader}{(\emph{string}) If is.timeSinceLastDose is TRUE,
dosingOccHeader needs to be expressed as header of the column containing
information to distinguish measurements that are after different doses (has
to be in occHeader as well).}

\item{timeFirstDose}{(\emph{double}) time of the first dose}

\item{doseInterval}{(\emph{double}) inter-dose interval To specify when
is.multiDose = TRUE}

\item{nbDoses}{(\emph{int}) number of doses To specify when is.multiDose =
TRUE}

\item{tInf}{(double) Infusion duration in case of IV infusion (default NULL)}

\item{doseAmount}{(\emph{bool}) Dose amount To specify when doseHeader = NULL}

\item{doseHeader}{(\emph{string}) Header of the column containing individual
dose amount}

\item{censTag}{(\emph{string} or \emph{vector}) Tag(s) representing censored
observation in the dataset. To define when lloq is not NULL (default tags
BLQ, BLOQ, CENS, LOQ, LLOQ).}

\item{lloq}{(\emph{double}) Lower Limit of quantification (default NULL)}

\item{dataSheet}{(\emph{string or int}) Sheet to read. Either a string (the
name of a sheet), or an integer (the position of the sheet). If several
data sheets are selected, they are merged. (default first sheet)}

\item{createProject}{(\emph{bool}) If TRUE, .pkx file will be created
automatically.}

\item{outputFilename}{(\emph{string}) Output file name. Can be absolute or
relative to the folder where the input dataset is stored. If the file
already exists, a new sheet is added to the file (by default the adapted
dataset is saved in a new file with the same extension and a name derived
from the original name) It can be a txt file, a csv file. For excel files,
only xlsx files can be returned. Output file name. Can be absolute or
relative to the folder where the input dataset is stored. It can be a txt,
csv or xlsx file. If an xlsx filename is given, a csv file with the same
name is also outputted.}

\item{catCov}{(\emph{vector}) Vector containing categorical covariate header
names.}

\item{contCov}{(\emph{vector}) Vector containing continuous covariate header
names.}

\item{export}{(\emph{bool}) To export .xlsx, .csv and .pkx file or not}
}
\value{
a dataframe with data in pkanalix format
}
\description{
Adapt the formatting of your dataset for use in PKanalix. In addition to
creating an adapted dataset, the function creates a PKanalix project based on
the adapted dataset and configured with the settings specified with
ncaSettings, beSettings and dataSettings, and the covariates specified with
catCov and contCov. See http://pkanalix.lixoft.com/data-formatting-macro/ for
more information
}
\details{
The following actions are performed \itemize{ \item A column AMT is added,
containing the same dosing regimen for all subjects or subject-occasions
(with an option to read individual dose amounts from a column of the dataset)
Note that the dosing times are correct in the column tagged as TIME in the
form, but other time columns will not be consistent. \item If the option
addOccperdose is TRUE (with multiple doses), two columns Dosing_OCC and
Time_LD are added containing occasion indexes for the different doses, and
the time after the last dose, respectively. \item If the option
is.timeSinceLastDose is TRUE, a header for the column containing occasion
marks for the different doses must be given, and it is treated as an occasion
column. \item In case of occasions, if the occasion column does not contain
only numbers, a new column OCC is added with occasion numbers. \item If an
occasion column is also specified as Administration Id, a new column ADM_ID
is added with integers for different administration ids. \item If several
observation columns are given, they are merged into a single column OBS and a
column OBS_ID is created to distinguish the different types of observations.
\item In case of urine data, the volume is set to 0 at dosing times to avoid
format errors, and both start and end times of the interval are set to the
dosing time. The function checks that time intervals are continuous (no gaps
are allowed). Only the column END TIME should be used as TIME in PKanalix.
\item In case of censored observations, a column CENS is added, containing 0
for non-censored observations and 1 for censored observations. The LLOQ is
written instead of the censoring tag in the column of observations. \item
Missing observations (all values that are not numbers) are replaced by '.'.
\item The first lines that do not contain data are concatenated into a single
header row. \item Rows that do not contain data are deleted. \item Formatting
is adapted for correct exporting to CSV format. }
}
\examples{
\dontrun{
  data <- data.frame(
    Id = rep(seq(3), each = 10),
    Time = rep(seq(0, 36, 4), 3),
    Y = rnorm(10 * 3, mean=10, sd=5)
   )
   file <- paste0(tempfile(), ".csv")
   write.table(x = data, file = file,
               row.names = FALSE, quote = FALSE)
   formatData(
     file, dataType = "plasma",
     idHeader = "Id", timeHeader = "Time",
     obsHeader = "Y",
     is.multiDose = FALSE, timeFirstDose = 0,
     is.doseInData = FALSE, doseAmount = 150,
   )
}
}
