% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlxReportPlots.R
\name{getBOXPLOT}
\alias{getBOXPLOT}
\title{Get boxplot of a variable as a ggplot2 object}
\usage{
getBOXPLOT(
  param,
  colorCat = NULL,
  renameCat = NULL,
  filterCat = NULL,
  splitCat = NULL,
  renameSplitCat = NULL,
  filterSplitCat = NULL,
  splitCat2 = NULL,
  renameSplitCat2 = NULL,
  filterSplitCat2 = NULL,
  addPoint = T,
  sameYlimit = T,
  colorMean = "black",
  addLine = NULL,
  addText = NULL,
  addLineColor = NULL,
  merge = T,
  ncol = NULL
)
}
\arguments{
\item{param}{(\emph{string}) NCA parameter to get box plot of.}

\item{colorCat}{(\emph{string}) Categorical covariate to color by.}

\item{renameCat}{(\emph{vector}) Display names of categories.}

\item{filterCat}{(\emph{vector}) Categories to filter.}

\item{splitCat}{(\emph{string}) Categorical covariate to split plots by.}

\item{renameSplitCat}{(\emph{vector}) Display names of categories.}

\item{filterSplitCat}{(\emph{vector}) Categories to filter.}

\item{splitCat2}{(\emph{string}) Categorical covariate to split plots by.}

\item{renameSplitCat2}{(\emph{vector}) Display names of categories.}

\item{filterSplitCat2}{(\emph{vector}) Categories to filter.}

\item{addPoint}{(\emph{bool}) If TRUE, points are shown on the plot}

\item{sameYlimit}{(\emph{bool}) If TRUE, all plots will have the same Y axis scale.}

\item{colorMean}{(\emph{string}) Color of the mean point.}

\item{addLine}{(\emph{double} or \emph{vector}) Value of y to display as horizontal line.}

\item{addText}{(\emph{string} or \emph{vector}) Text to show above horizontal line.}

\item{addLineColor}{(\emph{string} or \emph{vector}) Line color (e.g. "red", c("yellow", "red")).}

\item{merge}{(\emph{bool}) If TRUE, one object will be returned (default TRUE).}

\item{ncol}{(\emph{int}) Number of columns, if merge = FALSE.}
}
\value{
a ggplot2 object
}
\description{
Get boxplot of a variable as a ggplot2 object
}
\examples{
\dontrun{
library(lixoftConnectors)

initializeLixoftConnectors("pkanalix")
demoPath <- getDemoPath()
loadProject(paste0(demoPath, "/3.bioequivalence/project_crossover_bioequivalence.pkx"))
setNCASettings(
  partialAucTime = list(T, c(0, 24)),
  computedNCAParameters = c("AUCINF_obs", "Cmax", "Tmax", "Tlast")
)
runNCAEstimation()

boxPlot <- getBOXPLOT(
  param = "Cmax",
  splitCat = "FORM",
  renameSplitCat = c("ref" = "Reference", "test" = "Test"),
  addPoint = F
)
boxPlot
}

}
