% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlxReportTables.R
\name{getConcTable}
\alias{getConcTable}
\title{Table of measured drug concentrations}
\usage{
getConcTable(
  stat = c("Mean", "CV\%"),
  nbSignDigit = 3,
  displayOCC = T,
  vertCatName = NULL,
  renameVertCat = NULL,
  filterVertCat = NULL,
  vertCat2Name = NULL,
  renameVertCat2 = NULL,
  filterVertCat2 = NULL
)
}
\arguments{
\item{stat}{(\emph{vector}) Summary statistics to compute. Available options
are min, q1, median, q3, max, mean, sd, se, cv, cv\%, geomean, geosd, geocv,
geocv\%, hmean and n.}

\item{nbSignDigit}{(\emph{int}) Number of significant digits used to describe
the data.}

\item{displayOCC}{(\emph{bool}) Indicate occasion as a separate column next
to the ID column.}

\item{vertCatName}{(\emph{string}) Categorical covariate to split the data by
vertically.}

\item{renameVertCat}{(\emph{vector}) Displayed names for each vertCatName
modality.}

\item{filterVertCat}{(\emph{vector}) vertCatName modalities to filter out of
the table.}

\item{vertCat2Name}{(\emph{string}) Categorical covariate to split the data
by vertically.}

\item{renameVertCat2}{(\emph{vector}) Displayed names for each vertCat2Name
modality.}

\item{filterVertCat2}{(\emph{vector}) vertCat2Name modalities to filter out
of the table.}
}
\value{
A Flextable object.
}
\description{
\code{getConcTable} returns measured concentrations as a Flextable object.
}
\examples{
\dontrun{
library(lixoftConnectors)

initializeLixoftConnectors("pkanalix")
demoPath <- getDemoPath()
loadProject(paste0(demoPath, "/3.bioequivalence/project_crossover_bioequivalence.pkx"))
setNCASettings(
  partialAucTime = list(T, c(0, 24)),
  computedNCAParameters = c("AUCINF_obs", "Cmax", "Tmax", "Tlast")
)
runNCAEstimation()

CONCTABLE <- getConcTable(
  vertCatName = "FORM",
  renameVertCat = c("ref" = "Reference", "test" = "Test")
)
CONCTABLE
}

}
