% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlxReportTables.R
\name{getNCARatioTable}
\alias{getNCARatioTable}
\title{Table of individual NCA metrics expressed as ratios}
\usage{
getNCARatioTable(
  paramListIndiv = NULL,
  asMedian = NULL,
  stat = c("Mean", "CV\%"),
  nbSignDigit = 3,
  ratioCatName = NULL,
  renameRatioCat = NULL,
  filterRatioCat = NULL,
  horizCatName = NULL,
  renameHorizCat = NULL,
  filterHorizCat = NULL,
  vertCatName = NULL,
  renameVertCat = NULL,
  filterVertCat = NULL,
  vertCat2Name = NULL,
  renameVertCat2 = NULL,
  filterVertCat2 = NULL,
  ratioGain = 1,
  ratioRef = NULL,
  filterBy = NULL
)
}
\arguments{
\item{paramListIndiv}{(\emph{vector}) NCA metrics to be displayed in the
table. All available options can be found in the table
\href{https://pkanalix.lixoft.com/nca-parameters/}{here}.}

\item{asMedian}{(\emph{vector}) NCA metrics for which the calculated summary
statistics is median.}

\item{stat}{(\emph{vector}) Summary statistics to compute. Available options
are min, q1, median, q3, max, mean, sd, se, cv, cv\%, geomean, geosd, geocv,
geocv\%, hmean and n.}

\item{nbSignDigit}{(\emph{int}) Number of significant digits used to describe
the data.}

\item{ratioCatName}{(\emph{string}) Name of the categorical covariate to
divide the data by.}

\item{renameRatioCat}{(\emph{vector}) Displayed names for each of the
ratioCatName modalities.}

\item{filterRatioCat}{(\emph{vector}) Ratio category modalities to filter
out.}

\item{horizCatName}{(\emph{string}) Categorical covariate to split the data
by horizontally.}

\item{renameHorizCat}{(\emph{vector}) Displayed names for each of the
horizCatName modalities.}

\item{filterHorizCat}{(\emph{vector}) horizCatName modalities to filter out
of the table.}

\item{vertCatName}{(\emph{string}) Categorical covariate to split the data by
vertically.}

\item{renameVertCat}{(\emph{vector}) Displayed names for each vertCatName
modality.}

\item{filterVertCat}{(\emph{vector}) vertCatName modalities to filter out of
the table.}

\item{vertCat2Name}{(\emph{string}) Categorical covariate to split the data
by vertically.}

\item{renameVertCat2}{(\emph{vector}) Displayed names for each vertCat2Name
modality.}

\item{filterVertCat2}{(\emph{vector}) vertCat2Name modalities to filter out
of the table.}

\item{ratioGain}{(\emph{double}) A factor to multiply ratios with (e.g. 100,
if you want the ratios to be in \%).}

\item{ratioRef}{(\emph{string}) Ratio category modality with which all other
should be divided (if NULL, first modality).}

\item{filterBy}{(\emph{vector}) Vector containing one or more of the
following strings: "Flag_AUC_\%Extrap_pred", "Flag_Rsq_adjusted",
"Flag_Span". Note: included acceptance options need to be set in PKanalix
project in order for filtering to function properly.}
}
\value{
A Flextable object.
}
\description{
\code{getNCARatioTable} returns individual NCA parameters as a Flextable
object in the ratio format.
}
\examples{
\dontrun{
library(lixoftConnectors)

initializeLixoftConnectors("pkanalix")
demoPath <- getDemoPath()
loadProject(paste0(demoPath, "/3.bioequivalence/project_crossover_bioequivalence.pkx"))
setNCASettings(
  partialAucTime = list(T, c(0, 24)),
  computedNCAParameters = c("AUCINF_obs", "Cmax", "Tmax", "Tlast")
)
runNCAEstimation()

RATIOTABLE <- getNCARatioTable(
  paramListIndiv = c("AUCINF_obs", "Cmax", "AUC_0_24", "Tmax", "Tlast"),
  asMedian = c("Tmax", "Tlast"),
  stat = c("Mean", "CV\%", "HMean"),
  nbSignDigit = 4,
  ratioCatName = "FORM",
  renameRatioCat = c("ref" = "Reference", "test" = "Test"),
  vertCatName = "SEQ"
)
RATIOTABLE
}

}
