% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlxReportTables.R
\name{getNCASummaryTable}
\alias{getNCASummaryTable}
\title{Summary table of NCA metrics}
\usage{
getNCASummaryTable(
  paramListSummary = NULL,
  asMedian = NULL,
  stat = c("Mean", "CV\%"),
  nbSignDigit = 3,
  horizCatName = NULL,
  renameHorizCat = NULL,
  filterHorizCat = NULL,
  horizCat2Name = NULL,
  renameHorizCat2 = NULL,
  filterHorizCat2 = NULL,
  vertCatName = NULL,
  renameVertCat = NULL,
  filterVertCat = NULL,
  displayNbIndiv = T,
  filterBy = NULL,
  filterID = NULL,
  doseNormalizationUnit = NULL
)
}
\arguments{
\item{paramListSummary}{(\emph{vector}) NCA metrics to be displayed in the
table. All available options can be found in the table
\href{https://pkanalix.lixoft.com/nca-parameters/}{here}.}

\item{asMedian}{(\emph{vector}) NCA metrics for which the calculated summary
statistics is median.}

\item{stat}{(\emph{vector}) Summary statistics to compute. Available options
are min, q1, median, q3, max, mean, sd, se, cv, cv\%, geomean, geosd, geocv,
geocv\%, hmean and n.}

\item{nbSignDigit}{(\emph{int}) Number of significant digits used to describe
the data.}

\item{horizCatName}{(\emph{string}) Name of the categorical covariate to
split the data by horizontally.}

\item{renameHorizCat}{(\emph{vector}) Displayed names for each of the
horizCatName modalities.}

\item{filterHorizCat}{(\emph{vector}) Names of horizCatName modalities not to
be displayed in the table.}

\item{horizCat2Name}{(\emph{string}) Name of the categorical covariate to
split the data by horizontally in the second level.}

\item{renameHorizCat2}{(\emph{vector}) Displayed names for each of the
horizCat2Name modalities.}

\item{filterHorizCat2}{(\emph{vector}) Names of horizCat2Name modalities not
to be displayed in the table.}

\item{vertCatName}{(\emph{string}) Name of the categorical covariate to split
the data by vertically.}

\item{renameVertCat}{(\emph{vector}) Displayed names for each of the
vertCatName modalities.}

\item{filterVertCat}{(\emph{vector}) Names of vertCatName modalities not to
be displayed in the table.}

\item{displayNbIndiv}{(\emph{bool}) Display number of profiles used in the
calculation in the header.}

\item{filterBy}{(\emph{vector}) Vector containing one or more of the
following strings: "Flag_AUC_\%Extrap_pred", "Flag_Rsq_adjusted",
"Flag_Span". Note: included acceptance options need to be set in PKanalix
project in order for filtering to function properly.}

\item{filterID}{(\emph{vector}) Vector containing IDs of individuals to
filter out of the analysis.}

\item{doseNormalizationUnit}{(\emph{string}) String containing normalization
unit, if dose was normalized.}
}
\value{
A Flextable object.
}
\description{
\code{getNCASummaryTable} returns the summary table of NCA metrics as a
Flextable object.
}
\examples{
\dontrun{
library(lixoftConnectors)

initializeLixoftConnectors("pkanalix")
demoPath <- getDemoPath()
loadProject(paste0(demoPath, "/3.bioequivalence/project_crossover_bioequivalence.pkx"))
setNCASettings(
  partialAucTime = list(T, c(0, 24)),
  computedNCAParameters = c("AUCINF_obs", "Cmax", "Tmax", "Tlast")
)
runNCAEstimation()

NCASumTable <- getNCASummaryTable(
  paramListSummary = c("AUCINF_obs", "Cmax", "AUC_0_24", "Tmax", "Tlast"),
  asMedian = c("Tmax", "Tlast"),
  stat = c("Mean", "CV\%", "HMean"),
  nbSignDigit = 4,
  horizCatName = "FORM",
  renameHorizCat = c("ref" = "Reference", "test" = "Test"),
  vertCatName = "SEQ",
  filterID = c("1", "2")
)
NCASumTable
}

}
