% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlxReportPlots.R
\name{getPLOT_INDIVOBS}
\alias{getPLOT_INDIVOBS}
\title{Get mean observed data as ggplot2 object}
\usage{
getPLOT_INDIVOBS(
  xLab = "Time",
  yLab = "Plasma concentration",
  bLog = F,
  sameYlimit = T,
  filterCat = NULL,
  filterMod = NULL,
  splitCat = NULL,
  renameSplitCat = NULL,
  filterSplitCat = NULL,
  addLine = NULL,
  addText = NULL,
  addLineColor = NULL,
  merge = T
)
}
\arguments{
\item{xLab}{(\emph{string}) x-axis label.}

\item{yLab}{(\emph{string}) y-axis label.}

\item{bLog}{(\emph{bool} or \emph{"both"}) y-axis in log scale or both axes
in log scale.}

\item{sameYlimit}{(\emph{bool}) If TRUE, all plots will have the same y-axis
limit.}

\item{filterCat}{(\emph{vector}) Categories to filter.}

\item{filterMod}{(\emph{vector}) Categories to filter.}

\item{splitCat}{(\emph{string}) Categorical covariate to split plots by.}

\item{renameSplitCat}{(\emph{vector}) Display names of categories.}

\item{filterSplitCat}{(\emph{vector}) Categories to filter.}

\item{addLine}{(\emph{double} or \emph{vector}) Value of y to display as
horizontal line.}

\item{addText}{(\emph{string} or \emph{vector}) Text to show above horizontal
line.}

\item{addLineColor}{(\emph{string} or \emph{vector}) Line color (e.g. "red",
c("yellow", "red")).}

\item{merge}{(\emph{bool}) If TRUE, all plots will be merged to one (default
TRUE).}
}
\value{
a ggplot2 object
}
\description{
Get mean observed data as ggplot2 object
}
\examples{
\dontrun{
library(lixoftConnectors)

initializeLixoftConnectors("pkanalix")
demoPath <- getDemoPath()
loadProject(paste0(demoPath, "/3.bioequivalence/project_crossover_bioequivalence.pkx"))
setNCASettings(
  partialAucTime = list(T, c(0, 24)),
  computedNCAParameters = c("AUCINF_obs", "Cmax", "Tmax", "Tlast")
)
runNCAEstimation()

indivObs <- getPLOT_INDIVOBS(
  splitCat = "FORM",
  renameSplitCat = c("ref" = "Reference", "test" = "Test")
)
indivObs
}

}
