% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlxReportPlots.R
\name{getPLOT_MEANOBS}
\alias{getPLOT_MEANOBS}
\title{Plot mean observed data}
\usage{
getPLOT_MEANOBS(
  xLab = "Time",
  yLab = "Plasma concentration",
  bLog = F,
  sameYlimit = T,
  bCtrough = F,
  colorCat = NULL,
  renameCat = NULL,
  filterCat = NULL,
  colorCat2 = NULL,
  renameCat2 = NULL,
  filterCat2 = NULL,
  splitCat = NULL,
  renameSplitCat = NULL,
  filterSplitCat = NULL,
  addLine = NULL,
  addText = NULL,
  addLineColor = NULL,
  binsSettings = NULL
)
}
\arguments{
\item{xLab}{(\emph{string}) x-axis label.}

\item{yLab}{(\emph{string}) y-axis label.}

\item{bLog}{(\emph{bool} or \emph{"both"}) If TRUE, y-axis will be in in log
scale, if "both", both axes will be in log scale. FALSE by default.}

\item{sameYlimit}{(\emph{bool}) If TRUE and splitCat is defined, all plots
will have the same y-axis limits.}

\item{bCtrough}{(\emph{bool}) If TRUE, only Ctrough values will be plotted.}

\item{colorCat}{(\emph{string}) Categorical covariate to color stratify by.}

\item{renameCat}{(\emph{vector}) Displayed names of colorCat modalities.}

\item{filterCat}{(\emph{vector}) colorCat modalities to filter out.}

\item{colorCat2}{(\emph{string}) Categorical covariate to color stratify by.}

\item{renameCat2}{(\emph{vector}) Displayed names of colorCat modalities.}

\item{filterCat2}{(\emph{vector}) colorCat modalities to filter out.}

\item{splitCat}{(\emph{string}) Categorical covariate to split plots by.}

\item{renameSplitCat}{(\emph{vector}) Displayed names of splitCat modalities.}

\item{filterSplitCat}{(\emph{vector}) splitCat modalities to filter out.}

\item{addLine}{(\emph{double} or \emph{list}) Value of y to display as a
horizontal line (if double, it will be shown on all plots in case of
splits, otherwise need to specify modalities).}

\item{addText}{(\emph{string} or \emph{list}) Text to show above the
horizontal line, needs to have the same format as addLine.}

\item{addLineColor}{(\emph{string} or \emph{list}) Horizontal line color,
needs to have the same format as addLine.}

\item{binsSettings}{(\emph{string} or \emph{list}) a list of settings for
time axis binning for observation statistics computation. More details in
lixoftConnectors plotObservedData documentation.}
}
\value{
A ggplot2 object.
}
\description{
\code{getPLOT_MEANOBS} returns mean observed data plot as a ggplot2 object.
}
\examples{
\dontrun{
library(lixoftConnectors)

initializeLixoftConnectors("pkanalix")
demoPath <- getDemoPath()
loadProject(paste0(demoPath, "/3.bioequivalence/project_crossover_bioequivalence.pkx"))
setNCASettings(
  partialAucTime = list(T, c(0, 24)),
  computedNCAParameters = c("AUCINF_obs", "Cmax", "Tmax", "Tlast")
)
runNCAEstimation()

meanObs <- getPLOT_MEANOBS(
  splitCat = "FORM",
  renameSplitCat = c("ref" = "Reference", "test" = "Test"),
  colorCat = "SEQ"
)
meanObs
}

}
