% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlxReportTools.R
\name{replacePlaceholder}
\alias{replacePlaceholder}
\title{Replace the placeholders defined in the template document}
\usage{
replacePlaceholder(templatePath = NULL, objects, savePath = NULL)
}
\arguments{
\item{templatePath}{(\emph{string}) Path of the template document with .docx
extension.}

\item{objects}{(\emph{list}) List containing either: \itemize{ \item{if a
global variable name is the same as a placeholder defined in the document,
strings containing the names of variables containing objects (e.g.,
\code{"PLOT_MEANOBS"})} \item{strings with the names of placeholders pointing to
objects (e.g., \code{"PLOT_MEANOBS" = plotMeanObs})} \item{strings pointing to
lists or lists that consist of three elements: a string equal to a
placeholder name, or an object, and two integers, height and width of the
plot object replacing the placeholder, if the object is a plot (e.g.,
\code{list("PLOT_MEANOBS", 5, 5)}, \code{"PLOT_MEANOBS" = list(plotMeanObs, 5, 5)}).}
}}

\item{savePath}{(\emph{string}) Path for saving the document, ending in
.docx. Will overwrite the file with the same path, if it exists.}
}
\description{
Replace the placeholders defined in the template document
}
\examples{
\dontrun{
library(lixoftConnectors)

initializeLixoftConnectors("pkanalix")
demoPath <- getDemoPath()
loadProject(paste0(demoPath, "/3.bioequivalence/project_crossover_bioequivalence.pkx"))
setNCASettings(
  partialAucTime = list(T, c(0, 24)),
  computedNCAParameters = c("AUCINF_obs", "Cmax", "Tmax", "Tlast")
)
runNCAEstimation()

TABLE_NCA_SUMMARY <- getNCASummaryTable(
  paramListSummary = c("AUCINF_obs", "Cmax", "AUC_0_24", "Tmax", "Tlast"),
  asMedian = c("Tmax", "Tlast"),
  stat = c("Mean", "CV\%", "HMean"),
  nbSignDigit = 4,
  horizCatName = "FORM",
  renameHorizCat = c("ref" = "Reference", "test" = "Test"),
  vertCatName = "SEQ",
  filterID = c("1", "2")
)
PLOT_BOXPLOT_CMAX <- getBOXPLOT(
  param = "Cmax",
  splitCat = "FORM",
  renameSplitCat = c("ref" = "Reference", "test" = "Test"),
  addPoint = F
)
templatePath <- system.file("extdata", "Report_template_SAD.docx", package = "RsPKanalix")
replacePlaceholder(
  templatePath = templatePath,
  list("TABLE_NCA_SUMMARY",
       list("PLOT_BOXPLOT_CMAX", 5, 5),
       "DRUG_NAME" = "Theophylline 20 mg"),
  savePath = "generated_report.docx"
)
}

}
