test_that("string in occasion columns are processed correctly", {

  result <- formatData(dataFilename = "occasions/OccasionStrings.xlsx",
               idHeader = "ID", timeHeader = "TIME",
               obsHeader = "Y", occHeader = "FORM",
               doseAmount = 10, export = F)

  expected <- .readDataset("occasions/OccasionStrings_result.xlsx")
  expected[] <- lapply(expected, as.character)
  expect_equal(result, expected)
})

test_that("string in occasion columns with different numbers of strings are processed correctly", {

  result <- formatData(dataFilename = "occasions/OccasionStringsDiff.xlsx",
                         idHeader = "ID", timeHeader = "TIME",
                         obsHeader = "Y", occHeader = "FORM",
                         doseAmount = 10, export = F)

  expected <- .readDataset("occasions/OccasionStringsDiff_result.xlsx")
  expected[] <- lapply(expected, as.character)
  expect_equal(result, expected)
})

test_that("empty cell in the occasion column is processed correctly", {

  result <- formatData(dataFilename = "occasions/OccasionStringsEmpty.xlsx",
                         idHeader = "ID", timeHeader = "TIME",
                         obsHeader = "Y", occHeader = "FORM",
                         doseAmount = 10, export = F)

  expected <- .readDataset("occasions/OccasionStringsEmpty_result.xlsx")
  expected[] <- lapply(expected, as.character)
  expect_equal(result, expected)
})

test_that("multiple observation columns are processed correctly", {

  result <- formatData(dataFilename = "occasions/OccasionStringsMultiple.xlsx",
                         idHeader = "ID", timeHeader = "TIME",
                         obsHeader = "Y", occHeader = c("FORM", "FOOD"),
                         doseAmount = 10, export = F, doseInterval = 24,
                         nbDoses = 2, is.multiDose = T)

  expected <- .readDataset("occasions/OccasionStringsMultiple_result.xlsx")
  expected[] <- lapply(expected, as.character)
  expect_equal(result, expected)
})

test_that("administration ID column is processed correctly", {

  result <- formatData(dataFilename = "occasions/OccasionAdmID.xlsx",
                         idHeader = "ID", timeHeader = "TIME",
                         obsHeader = "Y", occHeader = "Period",
                         admIdHeader = "Period",
                         doseAmount = 10, export = F)

  expected <- .readDataset("occasions/OccasionAdmID_result.xlsx")
  expected[] <- lapply(expected, as.character)
  expect_equal(result, expected)
})

test_that("administration ID column is processed correctly when admIdHeader points to column with strings", {

  result <- formatData(dataFilename = "occasions/OccasionStringsAdmID.xlsx",
                         idHeader = "ID", timeHeader = "TIME",
                         obsHeader = "Y", occHeader = "FORM",
                         admIdHeader = "FORM", doseAmount = 10,
                         export = F)

  expected <- .readDataset("occasions/OccasionStringsAdmID_result.xlsx")
  expected[] <- lapply(expected, as.character)
  expect_equal(result, expected)
})

test_that("administration ID column is processed correctly when occHeader is a vector", {

  result <- formatData(dataFilename = "occasions/OccasionStringsAdmID.xlsx",
                         idHeader = "ID", timeHeader = "TIME",
                         obsHeader = "Y", occHeader = c("FORM", "Period"),
                         admIdHeader = "FORM", doseAmount = 10,
                         export = F)

  expected <- .readDataset("occasions/OccasionStringsAdmID_result.xlsx")
  expected[] <- lapply(expected, as.character)
  expect_equal(result, expected)
})

test_that("occasions are processed correctly when there are multiple observation headers", {

  result <- formatData(dataFilename = "occasions/OccasionObsColumns.xlsx",
                         idHeader = "ID", timeHeader = "TIME",
                         obsHeader = c("parent", "metab"),
                         occHeader = "FOOD", doseAmount = 10,
                         export = F)

  expected <- .readDataset("occasions/OccasionObsColumns_result.xlsx")
  expected[] <- lapply(expected, as.character)
  expect_equal(result, expected)
})

